/**
 * This class is the abstract of user's behavior ( a single action )
 */
package com.zkh.soot.analysis;

import soot.SootMethod;

/**
 * @author zkh
 *
 */
public class UserAction {
	private String classes;
	private String method;
	private String widget_name;
	private boolean self;
	private String action;
	private int count;
	private String value;
	private String input_filename;
	private SootMethod code = null;
	private String type;
	
	/**
	 * 
	 */
	public UserAction(String classes, String method, String widget_name, boolean self, String action,
			String count, String value) {
		this.classes = classes;
		this.method = method;
		this.widget_name = widget_name;
		this.self = self;
		this.action = action;
		
		if (count == "") {
			this.count = 1;
		} else {
			
			this.count = Integer.parseInt(count);
		}
		if (value == null)
			this.value = "";
		else
			this.value = value;
		if (value.isEmpty())
			this.input_filename = "";
		else
			this.input_filename = widget_name+"_input_value.txt";
	}
	public UserAction(String widget_name, String action, int count) {
		this.widget_name = widget_name;
		this.self = false;
		this.action = action;
		this.count = count;
		this.value = null;
		this.input_filename = null;
	}
	
	public UserAction(String widget_name,String action) {
		
		this.widget_name = widget_name;
		this.self = false;
		this.action = action;
		this.count = 1;
		this.value = null;
		this.input_filename = null;
	}

	public SootMethod getCode() {
		return code;
	}
	public String getClasses() {
		return classes;
	}
	public String getMethod() {
		return method;
	}
	public String getWidgetName() {
		return widget_name;
	}
	public String getType() {
		return type;
	}
	public String getAction() {
		return action;
	}
	public int getCount() {
		return count;
	}
	public String getValue() {
		return value;
	}
	public String getInputFilename() {
		return this.input_filename;
	}
	public boolean getSelf() {
		return self;
	}
	public boolean isParent() {
		return !self;
	}
	
	public void setCode(SootMethod code) {
		this.code = code;
	}
	public void setClasses(String classes) {
		this.classes = classes;
	}
	public void setMethod(String method) {
		this.method = method;
	}
	public void setWidgetName(String widget_name) {
		this.widget_name = widget_name;
	}
	public void setAction(String action) {
		this.action = action;
	}
	public void setCount(int count) {
		this.count = count;
	}
	public void setValue(String value) {
		this.value = value;
	}
	public void setInputFilename(String input_filename) {
		this.input_filename = input_filename;
	}
	public void setSelf(boolean self) {
		this.self = self;
	}
	
	public void setType(String type) {
		this.type = type;
	}

	public String toString() {
		return classes + "." + method + "." + widget_name + "." + action + ", self = " + this.self + ", count = " + this.count + ", value = " + this.value + ", input_filename = " + this.input_filename;
	}
}
